@@ -101,6 +101,15 @@ def client_constructor(engine: str, *args, **kwargs):
                                 v["_nest_database"],
                                 force_nested=True,
                             )
+                    elif isinstance(v, list):
+                        for i, li in enumerate(v):
+                            if "_nest_collection" in li:
+                                data[k][i] = self.map_document(
+                                    li["data"],
+                                    li["_nest_collection"],
+                                    li["_nest_database"],
+                                    force_nested=True,
+                                )
 
             _id = data.pop("_id", None)
             if _id:
@@ -278,6 +287,62 @@ def client_constructor(engine: str, *args, **kwargs):
                             {"_id": this._mongodb_id}, *args, **kwargs
                         )
 
+                    @staticmethod
+                    def find_class(
+                        *args,
+                        database: Union[str, pymongo.database.Database] = None,
+                        **kwargs,
+                    ) -> Optional[object]:
+                        """
+                        Find a single document from this class and convert it onto a mongoclass that maps to the collection of the document.
+
+                        Parameters
+                        ----------
+                        `*args` :
+                            Arguments to pass onto `find_one`.
+                        `database` : Union[str, Database]
+                            The database to use. Defaults to the default database.
+                        `**kwargs` :
+                            Keyword arguments to pass onto `find_one`.
+
+                        Returns
+                        -------
+                        `Optional[object]` :
+                            The mongoclass containing the document's data if it exists.
+                        """
+
+                        return self.find_class(
+                            collection_name, *args, database, **kwargs
+                        )
+
+                    @staticmethod
+                    def find_classes(
+                        *args,
+                        database: Union[str, pymongo.database.Database] = None,
+                        **kwargs,
+                    ) -> Cursor:
+                        """
+                        Find multiple document from this class s and return a `Cursor` that you can iterate over that contains the documents as a mongoclass.
+
+                        Parameters
+                        ----------
+                        `*args` :
+                            Arguments to pass onto `find`.
+                        `database` : Union[str, Database]
+                            The database to use. Defaults to the default database.
+                        `**kwargs` :
+                            Keyword arguments to pass onto `find`.
+
+                        Returns
+                        -------
+                        `Cursor`:
+                            A cursor similar to pymongo that you can iterate over to get the results.
+                        """
+
+                        return self.find_classes(
+                            collection_name, *args, database, **kwargs
+                        )
+
                     def as_json(this, perform_nesting: bool = nested) -> dict:
 
                         """
@@ -290,20 +355,42 @@ def client_constructor(engine: str, *args, **kwargs):
                         x.pop("_mongodb_id", None)
                         x.pop("_id", None)
 
+                        def create_nest_data(v, as_json):
+                            return {
+                                "data": as_json(perform_nesting),
+                                "_nest_collection": v._mongodb_collection,
+                                "_nest_database": v._mongodb_db.name,
+                            }
+
+                        def get_as_json(v):
+                            method = None
+                            try:
+                                method = getattr(
+                                    v,
+                                    "as_json",
+                                )
+                            except AttributeError:
+                                pass
+                            return method
+
                         if perform_nesting:
                             for k, v in copy.copy(x).items():
                                 if dataclasses.is_dataclass(v):
-                                    as_json_method = None
-                                    try:
-                                        as_json_method = getattr(v, "as_json")
-                                    except AttributeError:
-                                        pass
+                                    as_json_method = get_as_json(v)
                                     if as_json_method:
-                                        x[k] = {
-                                            "data": as_json_method(perform_nesting),
-                                            "_nest_collection": v._mongodb_collection,
-                                            "_nest_database": v._mongodb_db.name,
-                                        }
+                                        x[k] = create_nest_data(v, as_json_method)
+
+                                elif isinstance(v, list):
+                                    c = v.copy()
+                                    for i, li in enumerate(c):
+                                        if dataclasses.is_dataclass(li):
+                                            as_json_method = get_as_json(li)
+                                            if as_json_method:
+                                                c[i] = create_nest_data(
+                                                    li, as_json_method
+                                                )
+
+                                    x[k] = c
 
                         return x
 
